hdw.dat
=======

hdw.dat files for SuperDARN radars

Readme file for the hdw.dat repository.

This repository was setup by Kevin Sterne at Virginia Tech in order
to update the way hdw.dat files are maintained in the SuperDARN 
community.  The idea is that each institution is probably the best
source for their own radar's hdw.dat file and any applicable changes
to that file.  So, this respository will allow institutions to 
make updates to their hdw.dat file and allow other institutions to
download the latest version of the hdw.dat file.  
